==> qt-creator-2.3.0-src.zip: qt-creator-2.3.0-src/src/plugins/qmljstools/qmljstoolssettings.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#ifndef QMLJSTOOLSSETTINGS_H
#define QMLJSTOOLSSETTINGS_H

#include "qmljstools_global.h"

#include <QtCore/QObject>

namespace TextEditor
{
class TabPreferences;
}

namespace QmlJSTools
{

namespace Internal
{
class QmlJSToolsSettingsPrivate;
}

/**
 * This class provides a central place for cpp tools settings.
 */
class QMLJSTOOLS_EXPORT QmlJSToolsSettings : public QObject
{
    Q_OBJECT

public:
    explicit QmlJSToolsSettings(QObject *parent);
    ~QmlJSToolsSettings();

    static QmlJSToolsSettings *instance();

    TextEditor::TabPreferences *tabPreferences() const;

private:
    Internal::QmlJSToolsSettingsPrivate *m_d;

    static QmlJSToolsSettings *m_instance;
};

} // namespace QmlJSTools

#endif // QMLJSTOOLSSETTINGS_H

==> qt-creator-2.5.0-src.zip: qt-creator-2.5.0-src/src/plugins/qmljstools/qmljstoolssettings.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef QMLJSTOOLSSETTINGS_H
#define QMLJSTOOLSSETTINGS_H

#include "qmljstools_global.h"

#include <QObject>

namespace TextEditor
{
class SimpleCodeStylePreferences;
}

namespace QmlJSTools
{

namespace Internal
{
class QmlJSToolsSettingsPrivate;
}

/**
 * This class provides a central place for cpp tools settings.
 */
class QMLJSTOOLS_EXPORT QmlJSToolsSettings : public QObject
{
    Q_OBJECT

public:
    explicit QmlJSToolsSettings(QObject *parent);
    ~QmlJSToolsSettings();

    static QmlJSToolsSettings *instance();

    TextEditor::SimpleCodeStylePreferences *qmlJSCodeStyle() const;

private:
    Internal::QmlJSToolsSettingsPrivate *d;

    static QmlJSToolsSettings *m_instance;
};

} // namespace QmlJSTools

#endif // QMLJSTOOLSSETTINGS_H
